@@ -169,15 +169,30 @@ class Customer(object):
         """laquelle on calcul la conso fup d'un client"""
         result = {}
         key = 'cdr_start_date:{}'.format(self.name)
+        time_expire = datetime.strptime(
+            start_conso,
+            '%d%m%Y'
+            ) + timedelta(30) - datetime.strptime(
+            datetime.now().strftime('%d%m%Y'),
+            '%d%m%Y'
+            )
         REDIS_DB.set(key, start_conso)
-        REDIS_DB.expire(key, 2592000)
+        REDIS_DB.expire(
+            key,
+            int(time_expire.total_seconds())
+            )
         start = REDIS_DB.get(key)
         result = {
                 'code': '200',
                 'ident': self.name,
-                'date': str(start.decode('utf-8'))
+                'date': str(start.decode('utf-8')),
+                'expire': str(time_expire)
                 }
-        LOGS.logger.info('key enregistré:{}'.format(key))
+        LOGS.logger.info('key enregistré:{}-{}-{}'.format(
+            key,
+            start_conso,
+            time_expire
+            ))
         return result
 
     def fup_defup(
@@ -333,6 +348,7 @@ class Customer(object):
         import time
         url = core.database_url(**FUPDB_CREDENTIALS)
         LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
+
         OK = False
         for i in range(3):
             if OK:
@@ -466,10 +482,20 @@ class Customer(object):
                     "AND datetime>=:start AND datetime<=:stop"
                     ).format(self.table_cdr)
                 LOGS.logger.info(sql)
+                # start_date = date.strftime('%Y%m%d')+last_date[-6:]
+                start_date = datetime.strptime(
+                    str(last_date),
+                    '%Y%m%d%H%M%S'
+                    )
+                LOGS.logger.info('start {} stop {}'.format(
+                    start_date.strftime('%Y-%m-%d %H:%M:%S'),
+                    date.strftime('%Y-%m-%d 23:59:59')
+                    )
+                )
                 db.query(
                     sql,
                     name=self.name,
-                    start=date.strftime('%Y-%m-%d 00:00:00'),
+                    start=start_date.strftime('%Y-%m-%d %H:%M:%S'),
                     stop=date.strftime('%Y-%m-%d 23:59:59')
                     )
         if params:
@@ -812,13 +838,24 @@ class Customer(object):
             start=None,
             stop=None,
             daily_details=False,
-            product_out_fup=None
+            product_out_fup=None,
+            bool_start=False
             ):
         sources = ['cache', 'national', 'internet']
+        if not bool_start:
+            key = 'cdr_start_date:{}'.format(self.name)
+            start_date = REDIS_DB.get(key)
+            if start_date:
+                start = start_date.decode('utf-8')
+                start = datetime.strptime(start, '%d%m%Y').date()
         if not start:
             start = (datetime.now() - timedelta(30))
         if not stop:
             stop = (datetime.now() - timedelta(1))
+        LOGS.logger.info('start_date {} stop_date {}'.format(
+            start,
+            stop
+            ))
         cdrs = self.get_cdr(start, stop, product_out_fup)
         sorted_cdrs = sorted(
             cdrs,
